@@ -11,25 +11,22 @@
 #include <QCommandLineParser>
 
 #include <KLocalizedString>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <Kdelibs4ConfigMigrator>
+#endif
 #include <KCrash>
 #include <KAboutData>
 #include "klettres.h"
 #include "klettres_version.h"
 
-static const char description[] =
-    I18N_NOOP("KLettres helps a very young child or an adult learning \n"
-              "a new language by associating sounds and \n"
-              "letters in this language.\n\n"
-              "25 languages are available.");
-
 int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-
+#endif
     KLocalizedString::setApplicationDomain("klettres");
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QStringList configFiles;
     QStringList rcFiles;
     configFiles << QStringLiteral("klettresrc");
@@ -38,8 +35,12 @@ int main(int argc, char **argv)
     migrator.setConfigFiles(configFiles);
     migrator.setUiFiles(rcFiles);
     migrator.migrate();
+#endif
 
-    KAboutData about(QStringLiteral("klettres"), i18n("KLettres"), QStringLiteral(KLETTRES_VERSION_STRING), i18n(description),
+    KAboutData about(QStringLiteral("klettres"), i18n("KLettres"), QStringLiteral(KLETTRES_VERSION_STRING), i18n("KLettres helps a very young child or an adult learning \n"
+                                                                                                                 "a new language by associating sounds and \n"
+                                                                                                                 "letters in this language.\n\n"
+                                                                                                                 "25 languages are available."),
                      KAboutLicense::GPL, i18n("(C) 2001-2011 Anne-Marie Mahfouf"),QString(), QStringLiteral("https://edu.kde.org/klettres"), QStringLiteral("submit@bugs.kde.org"));
     about.addAuthor( i18n("Anne-Marie Mahfouf"), QString(), QStringLiteral("annma AT kde DOT org"), QStringLiteral("https://annma.blogspot.com"), QStringLiteral("annma"));
     about.addCredit(i18n("Marc Cheng"),
